@@ -1,18 +1,18 @@
-# $Id: Node.pm,v 1.7 2005/07/26 21:05:54 rvosa Exp $
-# Subversion: $Rev: 133 $
+# $Id: Node.pm,v 1.4 2005/08/01 23:06:18 rvosa Exp $
+# Subversion: $Rev: 147 $
 package Bio::Phylo::Trees::Node;
 use strict;
 use warnings;
-use base qw(Bio::Phylo);
+use base 'Bio::Phylo';
 
 # The bit of voodoo is for including Subversion keywords in the main source
 # file. $Rev is the subversion revision number. The way I set it up here allows
 # 'make dist' to build a *.tar.gz without the "_rev#" in the package name, while
 # it still shows up otherwise (e.g. during 'make test') as a developer release,
 # with the "_rev#".
-my $rev = '$Rev: 133 $';
+my $rev = '$Rev: 147 $';
 $rev =~ s/^[^\d]+(\d+)[^\d]+$/$1/;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 $VERSION .= '_' . $rev;
 my $VERBOSE = 1;
 use vars qw($VERSION);
@@ -75,16 +75,20 @@ sub new {
     $self->{'NEXT_SISTER'}     = undef;
     $self->{'PREVIOUS_SISTER'} = undef;
     $self->{'GENERIC'}         = {};
+    bless( $self, $class );
     if (@_) {
         my %opts = @_;
-        foreach my $key ( keys %opts ) {
-            my $localkey = $key;
-            $localkey =~ s/^\-(.+)$/$1/;
-            $localkey = uc($localkey);
-            $self->{$localkey} = $opts{$key};
+        while ( my ( $key, $value ) = each %opts ) {
+            my $localkey = uc(substr($key,1));
+            if ( exists $self->{$localkey} ) {
+                $self->{$localkey} = $value;
+            }
+            else {
+                $self->COMPLAIN("invalid field specified: $@");
+                return;
+            }
         }
     }
-    bless( $self, $class );
     return $self;
 }
 
@@ -1139,8 +1143,8 @@ Rutger Vos, C<< <rvosa@sfu.ca> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-phylo@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Phylo>.
+C<bug-bio-phylo@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Bio-Phylo>.
 I will be notified, and then you'll automatically be notified
 of progress on your bug as I make changes.
 
