@@ -1,21 +1,21 @@
-# $Id: Svg.pm,v 1.7 2005/07/27 15:48:57 rvosa Exp $
-# Subversion: $Rev: 133 $
+# $Id: Svg.pm,v 1.4 2005/08/01 23:06:19 rvosa Exp $
+# Subversion: $Rev: 147 $
 package Bio::Phylo::Unparsers::Svg;
 use strict;
 use warnings;
 use Bio::Phylo::Trees::Tree;
 use Bio::Phylo::Trees::Node;
 use SVG;
-use base qw(Bio::Phylo::Unparsers);
+use base 'Bio::Phylo::Unparsers';
 
 # The bit of voodoo is for including Subversion keywords in the main source
 # file. $Rev is the subversion revision number. The way I set it up here allows
 # 'make dist' to build a *.tar.gz without the "_rev#" in the package name, while
 # it still shows up otherwise (e.g. during 'make test') as a developer release,
 # with the "_rev#".
-my $rev = '$Rev: 133 $';
+my $rev = '$Rev: 147 $';
 $rev =~ s/^[^\d]+(\d+)[^\d]+$/$1/;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 $VERSION .= '_' . $rev;
 my $VERBOSE = 1;
 use vars qw($VERSION);
@@ -703,4 +703,34 @@ sub _timeline {
     }
     return $svg;
 }
+
+=back
+
+=head1 AUTHOR
+
+Rutger Vos, C<< <rvosa@sfu.ca> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to
+C<bug-bio-phylo@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Bio-Phylo>.
+I will be notified, and then you'll automatically be notified of
+progress on your bug as I make changes.
+
+=head1 ACKNOWLEDGEMENTS
+
+The author would like to thank Jason Stajich for many ideas borrowed
+from BioPerl L<http://www.bioperl.org>, and CIPRES
+L<http://www.phylo.org> and FAB* L<http://www.sfu.ca/~fabstar> for
+comments and requests.
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2005 Rutger Vos, All Rights Reserved.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
+
 1;
